import os
import requests
import logging
from kis_auth import get_valid_token

def get_search_conditions():
    access_token = get_valid_token()
    if not access_token:
        logging.error("Failed to obtain access token.")
        return None

    url = "https://openapi.koreainvestment.com:9443/uapi/domestic-stock/v1/quotations/psearch-title"
    headers = {
        'Content-Type': 'application/json; charset=utf-8',
        'Authorization': f'Bearer {access_token}',
        'appkey': os.getenv('MY_APP'),
        'appsecret': os.getenv('MY_SEC'),
        'tr_id': 'HHKST03900300'
    }
    params = {
        'user_id': os.getenv('USER_ID')
    }

    logging.info(f"Request URL: {url}")
    logging.info(f"Request Headers: {headers}")
    logging.info(f"Request Params: {params}")

    try:
        response = requests.get(url, headers=headers, params=params)
        if response.status_code == 200:
            data = response.json()
            logging.info(f"Search conditions response: {data}")
            return data['output2']
        else:
            logging.error(f"Error fetching search conditions: {response.text}")
            return None
    except requests.exceptions.RequestException as e:
        logging.error(f"Request exception occurred: {e}")
        return None

def fetch_stocks_by_condition(condition_seq):
    access_token = get_valid_token()
    if not access_token:
        logging.error("Failed to obtain access token.")
        return None

    url = "https://openapi.koreainvestment.com:9443/uapi/domestic-stock/v1/quotations/psearch-result"
    headers = {
        'Content-Type': 'application/json; charset=utf-8',
        'Authorization': f'Bearer {access_token}',
        'appkey': os.getenv('MY_APP'),
        'appsecret': os.getenv('MY_SEC'),
        'tr_id': 'HHKST03900400'
    }
    params = {
        'user_id': os.getenv('USER_ID'),
        'seq': condition_seq
    }

    logging.info(f"Request URL: {url}")
    logging.info(f"Request Headers: {headers}")
    logging.info(f"Request Params: {params}")

    try:
        response = requests.get(url, headers=headers, params=params)
        if response.status_code == 200:
            data = response.json()
            logging.info(f"Search results response: {data}")
            return data['output2']
        else:
            logging.error(f"Error fetching search results: {response.text}")
            return None
    except requests.exceptions.RequestException as e:
        logging.error(f"Request exception occurred: {e}")
        return None

def fetch_stock_data(stock_code):
    access_token = get_valid_token()
    api_key = os.getenv("MY_APP")
    api_secret = os.getenv("MY_SEC")
    
    url = f"https://openapi.koreainvestment.com:9443/uapi/domestic-stock/v1/quotations/inquire-price?FID_COND_MRKT_DIV_CODE=J&FID_INPUT_ISCD={stock_code}"
    headers = {
        'content-type': 'application/json; charset=utf-8',
        'authorization': f'Bearer {access_token}',
        'appkey': api_key,
        'appsecret': api_secret,
        'tr_id': 'FHKST01010100'
    }

    response = requests.get(url, headers=headers)
    
    if response.status_code == 200:
        return response.json()
    elif response.status_code == 401:
        logging.info("Token expired during fetch_stock_data request. Requesting new token.")
        access_token = refresh_token()
        return fetch_stock_data(stock_code)
    else:
        logging.error(f"Error fetching stock data for {stock_code}: {response.text}")
        return {}

def api_function():
    print("api_function called")
