import os
import torch
import logging
from stable_baselines3 import DQN
from stock_trading_env import StockTradingEnv
from settings import settings

# Configure logging
logging.basicConfig(level=logging.INFO)

# Set the device
device = 'cuda' if torch.cuda.is_available() else 'cpu'

def train_dqn_model(df, stock_code):
    """
    Train a DQN model on the given stock trading environment.

    Args:
    df (pandas.DataFrame): The stock data.
    stock_code (str): The stock code.

    Returns:
    None
    """
    # Initialize the stock trading environment
    env = StockTradingEnv(df)
    
    # Define the model path
    model_path = os.path.join(settings['model_path'], f"dqn_{stock_code}.zip")

    # Load existing model or create a new one
    if os.path.exists(model_path):
        model = DQN.load(model_path, env=env, device=device)
        logging.info(f"Model for {stock_code} loaded from {model_path}")
    else:
        model = DQN('MlpPolicy', env, verbose=1, device=device)
        logging.info(f"New model for {stock_code} created")

    # Train the model
    model.learn(total_timesteps=10000, reset_num_timesteps=False, log_interval=10)
    
    # Save the model
    model.save(model_path)
    logging.info(f"Model for {stock_code} saved to {model_path}")

def model_function():
    """
    A simple test function.
    
    Returns:
    None
    """
    print("model_function called")

# Remove example usage as this is for real use
